function [psi] = minus_projector_C2(psi,pars,mult_vec_proj)
% Apply the projector Pi_- to a two-component function 
%   psi = (psi_1,psi_2)^T.
% Input  must be in Fourier space!
% Output will be in Fourier space!

% psi is a vector of length 4*M:
% psi(    1:2*M) --> Fourier coefficients -M to M-1 of psi_1
% psi(2*M+1:4*M) --> Fourier coefficients -M to M-1 of psi_2
ep = pars.ep;

sz = size(psi);

M = sz(1)/4;
k_vec = transpose(2*pi/(pars.b-pars.a)*(-M:M-1));

if sz(2)==1 % psi is a vector
    psi = 0.5 * ( psi - repmat(mult_vec_proj,2,1) .* ...
                    [ ep*k_vec.*psi(2*M+1:4*M) + psi(    1:2*M) ; ...
                      ep*k_vec.*psi(    1:2*M) - psi(2*M+1:4*M)  ...
                     ] );
else % psi is a matrix
    psi = 0.5 * ( psi - repmat(mult_vec_proj,2,1) .* ...
                    [ ep*k_vec.*psi(2*M+1:4*M,:) + psi(    1:2*M,:) ; ...
                      ep*k_vec.*psi(    1:2*M,:) - psi(2*M+1:4*M,:) ...
                     ] );
end

end

