function [psi] = plus_projector_2C2(psi,pars,mult_vec_proj)
% Apply the projector Pi_+ to a four-component function 
%   psi = (psi^+ psi^-)^T = (psi^+_1,psi^+_2,psi^-_1,psi^-_2)^T.
% Input  must be in Fourier space!
% Output will be in Fourier space!

% psi is a vector of length 8*M:
% psi(    1:2*M) --> Fourier coefficients -M to M-1 of psi^+_1
% psi(2*M+1:4*M) --> Fourier coefficients -M to M-1 of psi^+_2
% psi(4*M+1:6*M) --> Fourier coefficients -M to M-1 of psi^-_1
% psi(6*M+1:8*M) --> Fourier coefficients -M to M-1 of psi^-_2
ep = pars.ep;

sz = size(psi);

M = sz(1)/8;
k_vec = transpose(2*pi/(pars.b-pars.a)*(-M:M-1));

if sz(2)==1 % psi is a vector
    psi = 0.5 * ( psi + repmat(mult_vec_proj,4,1) .* ...
                    [ ep*k_vec.*psi(2*M+1:4*M) + psi(    1:2*M) ; ...
                      ep*k_vec.*psi(    1:2*M) - psi(2*M+1:4*M) ; ...
                      ep*k_vec.*psi(6*M+1:8*M) + psi(4*M+1:6*M) ; ...
                      ep*k_vec.*psi(4*M+1:6*M) - psi(6*M+1:8*M) ...
                     ] );
else % psi is a matrix
    psi = 0.5 * ( psi + repmat(mult_vec_proj,4,1) .* ...
                    [ ep*k_vec.*psi(2*M+1:4*M,:) + psi(    1:2*M,:) ; ...
                      ep*k_vec.*psi(    1:2*M,:) - psi(2*M+1:4*M,:) ; ...
                      ep*k_vec.*psi(6*M+1:8*M,:) + psi(4*M+1:6*M,:) ; ...
                      ep*k_vec.*psi(4*M+1:6*M,:) - psi(6*M+1:8*M,:) ...
                     ] );
end

end