function [psi] = potential_W(psi,pars)
% Apply the potential W(x) = V(x) I_2 + A_1(x) alpha_1 to a four-component 
% function psi = (psi^+ psi^-)^T = (psi^+_1,psi^+_2,psi^-_1,psi^-_2)^T.
% Input  must be in space!
% Output will be in space!

% psi is a vector of length 8*M:
% Psi(    1:2*M) --> Psi^+_1 at the nodes x_(-M),...,x_(M-1)
% Psi(2*M+1:4*M) --> Psi^+_2 at the nodes x_(-M),...,x_(M-1)
% Psi(4*M+1:6*M) --> Psi^-_1 at the nodes x_(-M),...,x_(M-1)
% Psi(6*M+1:8*M) --> Psi^-_2 at the nodes x_(-M),...,x_(M-1)

% V and A_1 are vectors of length 2*M --> Evaluations of V and A_1 at knots
% x_(-M),...,x_(M-1)

sz = size(psi);

M = sz(1)/8;

% apply potential
if sz(2)==1 % psi is a vector
    psi = repmat(pars.V,4,1) .* psi - [ pars.A_1.*psi(2*M+1:4*M) ; ...
                                        pars.A_1.*psi(    1:2*M) ; ...
                                        pars.A_1.*psi(6*M+1:8*M) ; ...
                                        pars.A_1.*psi(4*M+1:6*M) ; ...
                                      ];
else % psi is a matrix
    psi = repmat(pars.V,4,1) .* psi - [ pars.A_1.*psi(2*M+1:4*M,:) ; ...
                                        pars.A_1.*psi(    1:2*M,:) ; ...
                                        pars.A_1.*psi(6*M+1:8*M,:) ; ...
                                        pars.A_1.*psi(4*M+1:6*M,:) ; ...
                                      ];
end
end

