function [psi] = retransform(phi,t,pars)
% Retransform phi to psi, i.e. calculate
% psi^+ = e^(-it/ep^2) phi^+
% psi^- = e^( it/ep^2) phi^-
% and add psi^+ and psi^-

% Input: phi is two two-component functions phi^+ and phi^-.
% --> phi is a vector of length 8*M
%       phi(    1:2*M,:) --> phi^+_1 at nodes x_(-M),...,x_(M-1)
%       psi(2*M+1:4*M,:) --> psi^+_2 at nodes x_(-M),...,x_(M-1)
%       phi(4*M+1:6*M,:) --> phi^-_1 at nodes x_(-M),...,x_(M-1)
%       psi(6*M+1:8*M,:) --> psi^-_2 at nodes x_(-M),...,x_(M-1)
% If phi has several columns: Each column is for one value of t --> length
% of t = number of columns of phi

% Output: psi is a two-component function discretizized on x_(-M),...,x_(M-1)
% --> psi is a vector of length 4*M
%       psi(    1:2*M,:) --> psi_1 at nodes x_(-M),...,x_(M-1)
%       psi(2*M+1:4*M,:) --> psi_2 at nodes x_(-M),...,x_(M-1)

M = size(phi,1)/8;

psi = exp(-1i*t/pars.ep^2) .* phi(    1:4*M,:) + ...
      exp( 1i*t/pars.ep^2) .* phi(4*M+1:8*M,:);
end

