function [vecs] = create_multiplication_vectors(pars)
% Creates a structure of multiplication vectors that are required
% repeatedly for the application of certain operators in Fourier space

ep = pars.ep; 
tau = pars.tau; 
M = pars.M;

k_vec = transpose(2*pi/(pars.b-pars.a)*(-M:M-1)); % Indices of Fourier modes;

%% Application of D --> mutliplication with k^2 / ( sqrt(1+ep^2k^2) + 1)
vecs.D = k_vec.^2 ./ ( sqrt(1+ep^2*k_vec.^2) + 1 );

%% Application of exp(i*tau*D) or exp(-i*tau*D)
vecs.expD_plus  = exp( 1i*tau*vecs.D);
vecs.expD_minus = exp(-1i*tau*vecs.D);
vecs.exp2D_plus  = exp( 2i*tau*vecs.D);
vecs.exp2D_minus = exp(-2i*tau*vecs.D);

% vecs.expD_plus_m2i_tau  = -2i*tau * exp( 1i*tau*vecs.D);
% vecs.expD_minus_m2i_tau = -2i*tau * exp(-1i*tau*vecs.D);


%% Application of projectors --> includes multiplication with 1/sqrt(1+ep^2k^2)
vecs.proj = 1./sqrt(1+ep^2*k_vec.^2);

%% Application of operators given by the integrals
% some integrals are of the form
%   int exp(mp i(tau-s)D) exp(dis/ep^2) ds
% --> Construct a function kappa = kappa( sign, d) that returns the
% multiplication vector (of length 2M) for the application of each integral

% we need the values of these integrals for d=-4,-2,0,2,4
% --> create two matrices to save them, one for sign + and one for sign -
% (remember that sign + --> - in the exponential operator)
vecs.kappa_pl = zeros(2*M,5);
vecs.kappa_mi = zeros(2*M,5);
d_vec = [-4,-2,0,2,4];
for d_ind = 1:5
    vecs.kappa_pl(:,d_ind) = kappa( 1, d_vec(d_ind), tau, ep, vecs.D);
    vecs.kappa_mi(:,d_ind) = kappa(-1, d_vec(d_ind), tau, ep, vecs.D);
end
 
% all other integrals are of the form
%   int exp(mp i(tau-s)D) s varphi_1(cis/ep^2) exp(dis/ep^2 ) ds
% --> Construct a function rho = rho( sign, c, d) that returns the
% multiplication vector (of length 2M) for the application of each integral

% for all values of d, d = -4,-2,0,2,4, we need the values of the integrals
% for c = -4,-2,0,2,4. Thus, for every value of d, we habe a matrix with 5
% columns.
c_vec = [-4,-2,0,2,4];

% Integrals for d = 0
vecs.int_d_0_pl = zeros(2*M,5);
vecs.int_d_0_mi = zeros(2*M,5);
for c_ind = 1:5
    vecs.int_d_0_pl(:,c_ind) = rho(  1, c_vec(c_ind), 0, tau, ep, vecs.D);
    vecs.int_d_0_mi(:,c_ind) = rho( -1, c_vec(c_ind), 0, tau, ep, vecs.D);
end


%% Integrals for two step method
% In the two step method, the integrals are of the form
%   int_{-tau}^tau exp(mp i(tau-s)D) exp(dis/ep^2) ds
% --> Construct a function kappa_2^pm(d) = kappa_2( sign, d) that returns the
% multiplication vector (of length 2M) for the application of each integral

% we need the values of these integrals for d=-4,-2,0,2,4
% --> create a matrix to save them, one for sign + and one for sign -
% (remember that sign + --> - in the exponential operator)
vecs.kappa_2_pl = zeros(2*M,5);
vecs.kappa_2_mi = zeros(2*M,5);
d_vec = [-4,-2,0,2,4];
for d_ind = 1:5
    vecs.kappa_2_pl(:,d_ind) = kappa_2( 1, d_vec(d_ind), tau, ep, vecs.D);
    vecs.kappa_2_mi(:,d_ind) = kappa_2(-1, d_vec(d_ind), tau, ep, vecs.D);
end

end

