function [psi] = ifft_2C2(psi)
% Calculate the Inverse Fourier transform for two two-component functions
% saved in psi

% psi is a vector of length 8*M:
% psi(    1:2*M) --> Fourier coefficients -M to M-1 of psi^+_1
% psi(2*M+1:4*M) --> Fourier coefficients -M to M-1 of psi^+_2
% psi(4*M+1:6*M) --> Fourier coefficients -M to M-1 of psi^-_1
% psi(6*M+1:8*M) --> Fourier coefficients -M to M-1 of psi^-_2

% --> Apply ifft_C2 to the first and second half of the vector psi seperately

% mat is a logical variable
% mat = 0 --> psi is a vector containing only one column
% mat = 1 --> psi is a matrix with several columns, apply ifft to each of
% them

sz = size(psi);

M = sz(1)/8;

if sz(2) == 1 % psi is a vector
    psi = [ ifft_C2( psi(1:4*M) ) ; ifft_C2( psi(4*M+1:8*M) ) ];
else % psi is a matrix
    psi = [ ifft_C2( psi(1:4*M,:) ) ; ifft_C2( psi(4*M+1:8*M,:) )];
end

end

