
% Input:  The Fourier coefficients fhat such that
%         f(x_j) = sum_{k=-kmax}^{kmax-1} fhat(k)*exp(i*k*x_j)
%                  if L is even, L = 2*kmax
%         f(x_j) = sum_{k=-kmax}^{kmax} fhat(k)*exp(i*k*x_j)
%                  if L is odd, L = 2*kmax+1
%         v(j) = fhat(-kmax-1+j),   j=1, ..., L
%
% Output: The function values of the 2pi-periodic function f:[-pi,pi] ---> IC
%         u(j) = f(x_j),   x_j=j*2pi/L
%         j=-kmax,...,kmax-1   if L=2*kmax   is even
%         j=-kmax,...,kmax     if L=2*kmax+1 is odd
%
% If the input is a matrix with more than one row (i.e. not a row vector), 
% then the operation is done column-wise.
% 
% WARNING: A row vector is treated like a column vector, NOT like a matrix.
% This makes a difference! 

function u = myifft(v)

s = size(v);
if length(s)>2
    fprintf('\n\n\n')
    fprintf('*** Error in myfft: The input must be a column vector or a matrix. *** \n\n\n')
    keyboard
end
L=s(1);
transp=0;
if L==1
    transp=1;
    v=v.';
    L=s(2);
end
if rem(L-1,2)>0
    % even
    kmax=round(L/2);
    v=v*L;
    v=ifftshift(v);
    u=ifft(v);
    u=fftshift(u);
else
    % odd
    kmax=round((L-1)/2);
    v=v*L;
    v=ifftshift(v);
    u=ifft(v);
    u=fftshift(u);
end

if transp==1
    u=u.';
end

% if 0
%     % Check result
%     ccc;
%     kmax=200;
%     L=2*kmax;
%     temp=-kmax+[0:L-1]';
%     x=2*pi*temp/L;
%     for j=1:L
%         k=-kmax+j-1;
%         u=exp(i*k*x);
%         v=zeros(L,1); v(j)=1;
%         uu=myifft(v);
%         temp(j)=norm(u-uu,inf);
%         if norm(u-uu,inf)>1e-10; keyboard; end
%     end
%     norm(temp,inf)
%     plot(temp)
%     
%     
%     clc; clear all hidden; kmax=1170; L=2*kmax+1; u=(rand(L,2)-0.5)*[1;1i];
%     v=myfft(u); uu=myifft(v); norm(u-uu)
% end
end




