function [phi_dt] = NLDE_transformed_right_side(t,phi,pars,vecs)

% Speicherstruktur des Vektors phi:
% 1:2*M:        phi_plus_1
% 2*M+1:4*M     phi_plus_2
% 4*M+1:6*M     phi_minus_1
% 6*M+1:8*M     phi_minus_2

%lambda_vec = (-M:M-1).^2./(sqrt(1+ep^2*(-M:M-1).^2)+1);
%mult_vec_proj = 1./sqrt( 1+ep^2 .* (-M:M-1).^2 )';

ep = pars.ep;
M = pars.M;

% Linear part
phi_four = fft_2C2(phi);
phi_dt_four = [-1i*vecs.lambda_vec;-1i*vecs.lambda_vec;1i*vecs.lambda_vec;1i*vecs.lambda_vec] .* phi_four;
% Nonlinearity + Potential part
if pars.gamma_1 ~= 0 % erste Art der Nichtlinearität
    phi_combined = phi + [exp(2i*t/ep^2)*phi(4*M+1:8*M); exp(-2i*t/ep^2)*phi(1:4*M)];
    % g_eps Vorfaktor
    abs_phi_squared = abs(phi).^2;
    exp__phi_p_conj_phi_m = exp(2i*t/ep^2) * ( conj(phi(1:2*M)).*phi(4*M+1:6*M) - conj(phi(2*M+1:4*M)).*phi(6*M+1:8*M) );
    g_eps_vec = pars.gamma_1 * ( abs_phi_squared(1:2*M) - abs_phi_squared(2*M+1:4*M) + ...
                                 abs_phi_squared(4*M+1:6*M) - abs_phi_squared(6*M+1:8*M) + ...
                                 2*real(exp__phi_p_conj_phi_m) );
    vec_g = repmat(g_eps_vec,4,1) .* phi_combined;
    vec_pot = potential_W(phi_combined,pars);
    W_and_g_phi_combined_four = myfft(vec_g + vec_pot);
elseif pars.gamma_2 ~= 0 % zweite Art der Nichtlinearität
    % g_eps
    abs_phi_p_squared = abs(phi(1:2*M)).^2 + abs(phi(2*M+1:4*M)).^2;
    abs_phi_m_squared = abs(phi(4*M+1:6*M)).^2 + abs(phi(6*M+1:8*M)).^2;
    phi_plus_conjugate_phi_minus = conj(phi(1:2*M)).*phi(4*M+1:6*M) + conj(phi(2*M+1:4*M)).*phi(6*M+1:8*M);
    exp_phi_plus_conjugate_phi_minus = exp(2i*t/ep^2) * phi_plus_conjugate_phi_minus;
    g_eps = abs_phi_p_squared + abs_phi_m_squared + 2*real(exp_phi_plus_conjugate_phi_minus);
    % Potential + Nonlinearity
    phi_combined = phi + [exp(2i*t/ep^2)*phi(4*M+1:8*M); exp(-2i*t/ep^2)*phi(1:4*M)];
    vec_g = pars.gamma_2 * repmat(g_eps,4,1) .* phi_combined;
    vec_pot = potential_W(phi_combined,pars);
    W_and_g_phi_combined_four = fft_2C2(vec_g + vec_pot);
else % Nur Potential
    phi_combined = phi + [exp(2i*t/ep^2)*phi(4*M+1:8*M); exp(-2i*t/ep^2)*phi(1:4*M)];
    vec_pot = potential_W(phi_combined,pars);
    W_and_g_phi_combined_four = myfft(vec_pot);
end

vec1 =  plus_projector_C2(W_and_g_phi_combined_four(    1:4*M),pars,vecs.proj);
vec2 = minus_projector_C2(W_and_g_phi_combined_four(4*M+1:8*M),pars,vecs.proj);

phi_dt_four = phi_dt_four - 1i* [vec1;vec2];
phi_dt = ifft_2C2(phi_dt_four);
end

