function [y] = compute_or_load_ref_solution(equation,rel_tol,abs_tol,pars)
% equation is 'limit system' or 'NLDE'

% filename for reference solution
filename_ref = [pars.base_fld,'/ref_solution ',equation,...
                ' rel_tol ',num2str(rel_tol), ...
                ' abs_tol ',num2str(abs_tol),'.mat'];

% load reference solution if existent, else compute it
if exist(filename_ref,'file') > 0
    load(filename_ref)
    disp(['Reference solution of ' equation ' has been loaded'])    
elseif strcmp(equation,'NLDE')
    % subdivide computation in several steps to prevent memory shortage
    if pars.ep > 0.01
        t_cut = 0.5;
    elseif pars.ep > 0.001
        t_cut = 0.05;
    else
        t_cut = 0.005;
    end
    % perform one step after another
    if pars.t_end > t_cut
        runs = floor( pars.t_end / t_cut);
        disp(['NLDE refference solution will be computed in ' num2str(runs) ' runs to prevent memory shortage']) 
        y = pars.psi_0;
        for r = 1:runs
            tic
            y = compute_reference_solution([(r-1)*t_cut,r*t_cut],y,rel_tol,abs_tol,filename_ref,pars,0);
            disp(['run ' num2str(r) ' of ' num2str(runs) ' completed (' num2str(toc) ' sec)'])
        end
        save(filename_ref,'y')
    else
        disp('Reference solution of NLDE is computed')    
        tic
        y = compute_reference_solution(pars.t_end,pars.psi_0,rel_tol,abs_tol,filename_ref,pars,1);
        disp(['NLDE solution with Matlab Solver has been computed, time ',...
              num2str(toc)])
    end
else % compute reference solution of limit system
    disp('Reference solution of limit system is computed')    
    tic
    y = compute_reference_solution_limit(pars.t_end,pars.psi_0,rel_tol,abs_tol,filename_ref,pars,1);
    disp(['Limit system solution with Matlab Solver has been computed, time ',...
          num2str(toc)])
end

end